@@ -80,7 +80,8 @@ plot.phreg <- function(x,
         Surviv <- pgompertz
         Dens <- dgompertz
         skal <- exp(x$coef[1]) / lambda # Kolla detta!!!!!!!!!!
-        for (i in 1:ns) p[i] <- skal
+        ##for (i in 1:ns) p[i] <- skal
+        for (i in 1:ns) p[i] <- exp(x$coef[1])
     }
 
     if ("haz" %in% fn){
